Fix "Avoid CamelCase" checkpatch.pl checks for function
parameters in ddk750_sii164.c.

Signed-off-by: Pavle Rohalj <pavle.roh...@gmail.com>
---
 drivers/staging/sm750fb/ddk750_sii164.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/staging/sm750fb/ddk750_sii164.c 
b/drivers/staging/sm750fb/ddk750_sii164.c
index a7e0f001d96f..869d74f53a6a 100644
--- a/drivers/staging/sm750fb/ddk750_sii164.c
+++ b/drivers/staging/sm750fb/ddk750_sii164.c
@@ -277,14 +277,14 @@ char *sii164_get_chip_string(void)
  *      This function sets the power configuration of the DVI Controller Chip.
  *
  *  Input:
  *      powerUp - Flag to set the power down or up
  */
-void sii164_set_power(unsigned char powerUp)
+void sii164_set_power(unsigned char power_up)
 {
        unsigned char config;
 
        config = i2c_read_reg(SII164_I2C_ADDRESS, SII164_CONFIGURATION);
-       if (powerUp == 1) {
+       if (power_up == 1) {
                /* Power up the chip */
                config &= ~SII164_CONFIGURATION_POWER_MASK;
                config |= SII164_CONFIGURATION_POWER_NORMAL;
@@ -302,13 +302,13 @@ void sii164_set_power(unsigned char powerUp)
  *      This function selects the mode of the hot plug detection.
  */
 static
-void sii164_select_hot_plug_detection_mode(enum sii164_hot_plug_mode 
hotPlugMode)
+void sii164_select_hot_plug_detection_mode(enum sii164_hot_plug_mode 
hot_plug_mode)
 {
        unsigned char detectReg;
 
        detectReg = i2c_read_reg(SII164_I2C_ADDRESS, SII164_DETECT) &
                    ~SII164_DETECT_MONITOR_SENSE_OUTPUT_FLAG;
-       switch (hotPlugMode) {
+       switch (hot_plug_mode) {
        case SII164_HOTPLUG_DISABLE:
                detectReg |= SII164_DETECT_MONITOR_SENSE_OUTPUT_HIGH;
                break;
@@ -332,9 +332,9 @@ void sii164_select_hot_plug_detection_mode(enum 
sii164_hot_plug_mode hotPlugMode
  *  sii164_enable_hot_plug_detection
  *      This function enables the Hot Plug detection.
  *
  *  enableHotPlug   - Enable (=1) / disable (=0) Hot Plug detection
  */
-void sii164_enable_hot_plug_detection(unsigned char enableHotPlug)
+void sii164_enable_hot_plug_detection(unsigned char enable_hot_plug)
 {
        unsigned char detectReg;
 
@@ -343,7 +343,7 @@ void sii164_enable_hot_plug_detection(unsigned char 
enableHotPlug)
        /* Depending on each DVI controller, need to enable the hot plug based
         * on each individual chip design.
         */
-       if (enableHotPlug != 0)
+       if (enable_hot_plug != 0)
                sii164_select_hot_plug_detection_mode(SII164_HOTPLUG_USE_MDI);
        else
                sii164_select_hot_plug_detection_mode(SII164_HOTPLUG_DISABLE);
@@ -277,14 +277,14 @@ char *sii164_get_chip_string(void)
  *
  *  Input:
- *      powerUp - Flag to set the power down or up
+ *      power_up - Flag to set the power down or up
  */
@@ -332,9 +332,9 @@ void sii164_select_hot_plug_detection_mode(enum 
  *      This function enables the Hot Plug detection.
  *
- *  enableHotPlug   - Enable (=1) / disable (=0) Hot Plug detection
+ *  enable_hot_plug   - Enable (=1) / disable (=0) Hot Plug detection
  */
-- 
2.30.2

Reply via email to